about summary refs log tree commit diff
diff options
context:
space:
mode:
authorJaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@gmail.com>2015-02-21 19:31:39 +0100
committerJaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@gmail.com>2015-02-21 19:31:39 +0100
commit93540ee10e4143f8de7885af2d68c213aab7d8cb (patch)
tree7facbf0ed2b2c976ca182248388ff826006234a9
parent8fb3ac3649ca7df6f328971f58afa84dd9d05cc6 (diff)
downloadyoutube-dl-93540ee10e4143f8de7885af2d68c213aab7d8cb.tar.gz
youtube-dl-93540ee10e4143f8de7885af2d68c213aab7d8cb.tar.xz
youtube-dl-93540ee10e4143f8de7885af2d68c213aab7d8cb.zip
[rtve] Fix the video url
Changing mvod to mvod1 fixes the url, we don't need to add the query.
-rw-r--r--youtube_dl/extractor/rtve.py9
1 files changed, 4 insertions, 5 deletions
diff --git a/youtube_dl/extractor/rtve.py b/youtube_dl/extractor/rtve.py
index 3469d9578..e60f85b5b 100644
--- a/youtube_dl/extractor/rtve.py
+++ b/youtube_dl/extractor/rtve.py
@@ -6,6 +6,7 @@ import re
 import time
 
 from .common import InfoExtractor
+from ..compat import compat_urlparse
 from ..utils import (
     struct_unpack,
     remove_end,
@@ -96,12 +97,10 @@ class RTVEALaCartaIE(InfoExtractor):
             ).replace('.net.rtve', '.multimedia.cdn.rtve')
             video_path = self._download_webpage(
                 auth_url, video_id, 'Getting video url')
             # Use mvod.akcdn instead of flash.akamaihd.multimedia.cdn to get
             # the right Content-Length header and the mp4 format
-            video_url = (
-                'http://mvod.akcdn.rtve.es/{0}&v=2.6.8'
-                '&fp=MAC%2016,0,0,296&r=MRUGG&g=OEOJWFXNFGCP'.format(video_path)
-            )
+            video_url = compat_urlparse.urljoin(
+                'http://mvod1.akcdn.rtve.es/', video_path)
 
         return {
             'id': video_id,
@@ -96,12 +97,10 @@ class RTVEALaCartaIE(InfoExtractor):
             video_path = self._download_webpage(
                 auth_url, video_id, 'Getting video url')
-            # Use mvod.akcdn instead of flash.akamaihd.multimedia.cdn to get
+            # Use mvod1.akcdn instead of flash.akamaihd.multimedia.cdn to get
             # the right Content-Length header and the mp4 format